import os
import pyarrow.parquet as pa_parquet

from src.platform.benchmarking.mock_parquet_generator import MockParquetGenerator

from concurrent.futures import ProcessPoolExecutor


def generate_file(i):
    mpg = MockParquetGenerator()
    mpg_res = mpg.generate_sample_pa_table(10_000, 10_000 * i)
    pa_parquet.write_table(mpg_res, f"generated_data/{i}.parquet")


def main(generate_mode=False):
    if generate_mode:
        with ProcessPoolExecutor(max_workers=os.cpu_count()) as executor:
            futures = [
                executor.submit(
                    generate_file,
                    i,
                )
                for i in list(range(0, 10_000))
            ]
            for future in futures:
                future.result()


if __name__ == "__main__":
    main(generate_mode=True)
