import pyarrow
import pyarrow as pa

_SAMPLE_SCHEMA = pa.schema(
    [
        pa.field("name", pa.string()),
        pa.field("id", pa.int64()),
        pa.field("mod_ten", pa.string()),
    ]
)


class MockParquetGenerator:
    def __init__(self):
        pass

    def generate_sample_pa_table(self, size: int, offset: int = 0) -> pyarrow.Table:
        records = []

        for i in range(offset, offset + size):
            records.append(
                {
                    "name": _int_to_alphabet(i),
                    "id": i,
                    "mod_ten": str(i % 10),
                }
            )
        return pa.Table.from_pylist(records, schema=_SAMPLE_SCHEMA)


def _int_to_alphabet(number):
    """Converts an integer to a string of alphabets.
    Args:
        number: The integer to convert.
    Returns:
        A string of alphabets representing the integer.
    """
    if number < 0:
        raise ValueError("Number must be non-negative.")
    alphabet = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
    result = []
    while number > 0:
        result.append(alphabet[number % 26])
        number //= 26
    result.reverse()
    return "".join(result)
